@@ -154,29 +154,6 @@ static const GOptionEntry COMMAND_LINE_OPTIONS[] =
   { NULL }
 };
 
-static const gchar *REQUIRED_GEGL_OPS[] =
-{
-  "gegl:buffer-sink",
-  "gegl:buffer-source",
-  "gegl:crop",
-  "gegl:exposure",
-  "gegl:gray",
-  "gegl:load",
-  "gegl:noise-reduction",
-  "gegl:nop",
-  "gegl:pixbuf",
-  "gegl:rotate-on-center",
-  "gegl:save-pixbuf",
-  "gegl:scale-ratio",
-  "gegl:unsharp-mask",
-
-  /* Used by gegl:load */
-  "gegl:jpg-load",
-  "gegl:png-load",
-  "gegl:raw-load",
-  "gegl:text"
-};
-
 static const gchar *DESKTOP_BACKGROUND_SCHEMA = "org.gnome.desktop.background";
 static const gchar *DESKTOP_SCREENSAVER_SCHEMA = "org.gnome.desktop.screensaver";
 static const gchar *DESKTOP_KEY_PICTURE_URI = "picture-uri";
@@ -187,6 +164,7 @@ static const gchar *DESKTOP_KEY_SECONDARY_COLOR = "secondary-color";
 
 typedef struct _PhotosApplicationCreateData PhotosApplicationCreateData;
 typedef struct _PhotosApplicationRefreshData PhotosApplicationRefreshData;
+typedef struct _PhotosApplicationSetBackgroundData PhotosApplicationSetBackgroundData;
 
 struct _PhotosApplicationCreateData
 {
@@ -201,6 +179,12 @@ struct _PhotosApplicationRefreshData
   GomMiner *miner;
 };
 
+struct _PhotosApplicationSetBackgroundData
+{
+  GFile *file;
+  GSettings *settings;
+};
+
 static void photos_application_refresh_miner_now (PhotosApplication *self, GomMiner *miner);
 static void photos_application_start_miners (PhotosApplication *self);
 static void photos_application_start_miners_second (PhotosApplication *self);
@@ -255,6 +239,27 @@ photos_application_refresh_data_free (PhotosApplicationRefreshData *data)
 }
 
 
+static PhotosApplicationSetBackgroundData *
+photos_application_set_background_data_new (GFile *file, GSettings *settings)
+{
+  PhotosApplicationSetBackgroundData *data;
+
+  data = g_slice_new0 (PhotosApplicationSetBackgroundData);
+  data->file = g_object_ref (file);
+  data->settings = g_object_ref (settings);
+  return data;
+}
+
+
+static void
+photos_application_set_background_data_free (PhotosApplicationSetBackgroundData *data)
+{
+  g_object_unref (data->file);
+  g_object_unref (data->settings);
+  g_slice_free (PhotosApplicationSetBackgroundData, data);
+}
+
+
 static void
 photos_application_help (PhotosApplication *self, GVariant *parameter)
 {
@@ -571,32 +576,6 @@ photos_application_gegl_init_fishes_idle (gpointer user_data)
 }
 
 
-static gboolean
-photos_application_sanity_check_gegl (PhotosApplication *self)
-{
-  GeglConfig *config;
-  gboolean ret_val = TRUE;
-  gboolean use_opencl;
-  guint i;
-
-  config = gegl_config ();
-  g_object_get (config, "use-opencl", &use_opencl, NULL);
-  photos_debug (PHOTOS_DEBUG_GEGL, "Using OpenCL: %s", use_opencl ? "yes" : "no");
-
-  for (i = 0; i < G_N_ELEMENTS (REQUIRED_GEGL_OPS); i++)
-    {
-      if (!gegl_has_operation (REQUIRED_GEGL_OPS[i]))
-        {
-          g_warning ("Unable to find GEGL operation %s: Check your GEGL install", REQUIRED_GEGL_OPS[i]);
-          ret_val = FALSE;
-          break;
-        }
-    }
-
-  return ret_val;
-}
-
-
 static void
 photos_application_tracker_set_rdf_types (GObject *source_object, GAsyncResult *res, gpointer user_data)
 {
@@ -650,22 +629,22 @@ photos_application_tracker_extract_priority (GObject *source_object, GAsyncResul
 static gboolean
 photos_application_create_window (PhotosApplication *self)
 {
+  gboolean gegl_sanity_checked;
   gboolean gexiv2_initialized;
   gboolean gexiv2_registered_namespace;
-  gboolean sanity_checked_gegl;
 
   if (self->main_window != NULL)
     return TRUE;
 
+  gegl_sanity_checked = photos_gegl_sanity_check ();
+  g_return_val_if_fail (gegl_sanity_checked, FALSE);
+
   gexiv2_initialized = gexiv2_initialize ();
   g_return_val_if_fail (gexiv2_initialized, FALSE);
 
   gexiv2_registered_namespace = gexiv2_metadata_register_xmp_namespace ("http://www.gnome.org/xmp", "gnome");
   g_return_val_if_fail (gexiv2_registered_namespace, FALSE);
 
-  sanity_checked_gegl = photos_application_sanity_check_gegl (self);
-  g_return_val_if_fail (sanity_checked_gegl, FALSE);
-
   self->main_window = photos_main_window_new (GTK_APPLICATION (self));
   g_signal_connect_object (self->main_window,
                            "delete-event",
@@ -1209,7 +1188,7 @@ photos_application_quit (PhotosApplication *self, GVariant *parameter)
 
 
 static void
-photos_application_save_save (GObject *source_object, GAsyncResult *res, gpointer user_data)
+photos_application_save_save_to_dir (GObject *source_object, GAsyncResult *res, gpointer user_data)
 {
   PhotosApplication *self = PHOTOS_APPLICATION (user_data);
   PhotosBaseItem *item = PHOTOS_BASE_ITEM (source_object);
@@ -1217,7 +1196,7 @@ photos_application_save_save (GObject *source_object, GAsyncResult *res, gpointe
   GFile *file = NULL;
   GList *items = NULL;
 
-  file = photos_base_item_save_finish (item, res, &error);
+  file = photos_base_item_save_to_dir_finish (item, res, &error);
   if (error != NULL)
     {
       g_warning ("Unable to save: %s", error->message);
@@ -1297,7 +1276,7 @@ photos_application_save_response (GtkDialog *dialog, gint response_id, gpointer
   zoom = photos_export_dialog_get_zoom (PHOTOS_EXPORT_DIALOG (dialog));
 
   g_application_hold (G_APPLICATION (self));
-  photos_base_item_save_async (item, export, zoom, NULL, photos_application_save_save, self);
+  photos_base_item_save_to_dir_async (item, export, zoom, NULL, photos_application_save_save_to_dir, self);
 
  out:
   g_free (export_path);
@@ -1323,49 +1302,86 @@ photos_application_save (PhotosApplication *self)
 
 
 static void
-photos_application_set_bg_common_download (GObject *source_object, GAsyncResult *res, gpointer user_data)
+photos_application_set_bg_common_save_to_file (GObject *source_object, GAsyncResult *res, gpointer user_data)
 {
   PhotosBaseItem *item = PHOTOS_BASE_ITEM (source_object);
   GError *error;
-  GSettings *settings = G_SETTINGS (user_data);
-  gchar *filename = NULL;
+  PhotosApplicationSetBackgroundData *data = (PhotosApplicationSetBackgroundData *) user_data;
+  gchar *path = NULL;
 
   error = NULL;
-  filename = photos_base_item_download_finish (item, res, &error);
-  if (error != NULL)
+  if (!photos_base_item_save_to_file_finish (item, res, &error))
     {
-      const gchar *uri;
-
-      uri = photos_base_item_get_uri (item);
-      g_warning ("Unable to extract the local filename for %s", uri);
+      g_warning ("Unable to set background: %s", error->message);
       g_error_free (error);
       goto out;
     }
 
-  g_settings_set_string (settings, DESKTOP_KEY_PICTURE_URI, filename);
-  g_settings_set_enum (settings, DESKTOP_KEY_PICTURE_OPTIONS, G_DESKTOP_BACKGROUND_STYLE_ZOOM);
-  g_settings_set_enum (settings, DESKTOP_KEY_COLOR_SHADING_TYPE, G_DESKTOP_BACKGROUND_SHADING_SOLID);
-  g_settings_set_string (settings, DESKTOP_KEY_PRIMARY_COLOR, "#000000000000");
-  g_settings_set_string (settings, DESKTOP_KEY_SECONDARY_COLOR, "#000000000000");
+  path = g_file_get_path (data->file);
+
+  g_settings_set_string (data->settings, DESKTOP_KEY_PICTURE_URI, path);
+  g_settings_set_enum (data->settings, DESKTOP_KEY_PICTURE_OPTIONS, G_DESKTOP_BACKGROUND_STYLE_ZOOM);
+  g_settings_set_enum (data->settings, DESKTOP_KEY_COLOR_SHADING_TYPE, G_DESKTOP_BACKGROUND_SHADING_SOLID);
+  g_settings_set_string (data->settings, DESKTOP_KEY_PRIMARY_COLOR, "#000000000000");
+  g_settings_set_string (data->settings, DESKTOP_KEY_SECONDARY_COLOR, "#000000000000");
 
  out:
-  g_free (filename);
-  g_object_unref (settings);
+  g_free (path);
+  photos_application_set_background_data_free (data);
 }
 
 
 static void
 photos_application_set_bg_common (PhotosApplication *self, GVariant *parameter, gpointer user_data)
 {
+  GFile *backgrounds_file = NULL;
   GSimpleAction *action = G_SIMPLE_ACTION (user_data);
   GSettings *settings;
+  PhotosApplicationSetBackgroundData *data;
   PhotosBaseItem *item;
+  const gchar *config_dir;
+  const gchar *extension;
+  const gchar *filename;
+  const gchar *mime_type;
+  gchar *backgrounds_dir = NULL;
+  gchar *backgrounds_filename = NULL;
+  gchar *backgrounds_path = NULL;
+  gchar *basename = NULL;
+  gint64 now;
 
   item = PHOTOS_BASE_ITEM (photos_base_manager_get_active_object (self->state->item_mngr));
   g_return_if_fail (item != NULL);
 
+  config_dir = g_get_user_config_dir ();
+  backgrounds_dir = g_build_filename (config_dir, PACKAGE_TARNAME, "backgrounds", NULL);
+  g_mkdir_with_parents (backgrounds_dir, 0700);
+
+  now = g_get_monotonic_time ();
+  filename = photos_base_item_get_filename (item);
+  basename = photos_glib_filename_strip_extension (filename);
+  mime_type = photos_base_item_get_mime_type (item);
+  extension = g_strcmp0 (mime_type, "image/png") == 0 ? ".png" : ".jpg";
+
+  backgrounds_filename = g_strdup_printf ("%" G_GINT64_FORMAT "-%s%s", now, basename, extension);
+  backgrounds_path = g_build_filename (backgrounds_dir, backgrounds_filename, NULL);
+  backgrounds_file = g_file_new_for_path (backgrounds_path);
+
   settings = G_SETTINGS (g_object_get_data (G_OBJECT (action), "settings"));
-  photos_base_item_download_async (item, NULL, photos_application_set_bg_common_download, g_object_ref (settings));
+
+  data = photos_application_set_background_data_new (backgrounds_file, settings);
+  photos_base_item_save_to_file_async (item,
+                                       backgrounds_file,
+                                       G_FILE_CREATE_PRIVATE | G_FILE_CREATE_REPLACE_DESTINATION,
+                                       1.0,
+                                       NULL,
+                                       photos_application_set_bg_common_save_to_file,
+                                       data);
+
+  g_object_unref (backgrounds_file);
+  g_free (backgrounds_dir);
+  g_free (backgrounds_filename);
+  g_free (backgrounds_path);
+  g_free (basename);
 }
 
 
@@ -1673,7 +1689,7 @@ photos_application_startup (GApplication *application)
 
   G_APPLICATION_CLASS (photos_application_parent_class)->startup (application);
 
-  gegl_init (NULL, NULL);
+  photos_gegl_init ();
 
   grl_init (NULL, NULL);
   registry = grl_registry_get_default ();
