@@ -31,6 +31,7 @@
 #include "photos-operation-jpg-guess-sizes.h"
 #include "photos-operation-png-guess-sizes.h"
 #include "photos-operation-saturation.h"
+#include "photos-operation-svg-multiply.h"
 #include "photos-quarks.h"
 
 
@@ -44,6 +45,29 @@ static const struct
   { "R'G'B' u8", "YA float" }
 };
 
+static const gchar *REQUIRED_GEGL_OPS[] =
+{
+  "gegl:buffer-sink",
+  "gegl:buffer-source",
+  "gegl:crop",
+  "gegl:exposure",
+  "gegl:gray",
+  "gegl:load",
+  "gegl:noise-reduction",
+  "gegl:nop",
+  "gegl:pixbuf",
+  "gegl:rotate-on-center",
+  "gegl:save-pixbuf",
+  "gegl:scale-ratio",
+  "gegl:unsharp-mask",
+
+  /* Used by gegl:load */
+  "gegl:jpg-load",
+  "gegl:png-load",
+  "gegl:raw-load",
+  "gegl:text"
+};
+
 
 static GeglBuffer *
 photos_gegl_buffer_zoom (GeglBuffer *buffer, gdouble zoom, GCancellable *cancellable, GError **error)
@@ -228,6 +252,7 @@ photos_gegl_ensure_builtins (void)
       g_type_ensure (PHOTOS_TYPE_OPERATION_JPG_GUESS_SIZES);
       g_type_ensure (PHOTOS_TYPE_OPERATION_PNG_GUESS_SIZES);
       g_type_ensure (PHOTOS_TYPE_OPERATION_SATURATION);
+      g_type_ensure (PHOTOS_TYPE_OPERATION_SVG_MULTIPLY);
 
       g_once_init_leave (&once_init_value, 1);
     }
@@ -264,6 +289,32 @@ photos_gegl_get_buffer_from_node (GeglNode *node, const Babl *format)
 }
 
 
+void
+photos_gegl_init (void)
+{
+  GeglConfig *config;
+  gint threads;
+  guint num_processors;
+
+  gegl_init (NULL, NULL);
+
+  num_processors = g_get_num_processors ();
+  g_return_if_fail (num_processors > 0);
+
+  /* The number of threads should match the number of physical CPU
+   * cores, not the number of virtual hyper-threading cores. In the
+   * absence of an API to get the number of physical CPU cores, we
+   * assume that a number higher than one is indicative of
+   * hyper-threading, and hence divide by two.
+   */
+  threads = (gint) (num_processors > 1 ? num_processors / 2 : num_processors);
+
+  config = gegl_config ();
+  g_object_set (config, "threads", threads, NULL);
+  g_object_set (config, "use-opencl", FALSE, NULL);
+}
+
+
 void
 photos_gegl_init_fishes (void)
 {
@@ -372,3 +423,31 @@ photos_gegl_remove_children_from_node (GeglNode *node)
 
   gegl_node_link (input, output);
 }
+
+
+gboolean
+photos_gegl_sanity_check (void)
+{
+  GeglConfig *config;
+  gboolean ret_val = TRUE;
+  gboolean use_opencl;
+  gint threads;
+  guint i;
+
+  config = gegl_config ();
+  g_object_get (config, "threads", &threads, "use-opencl", &use_opencl, NULL);
+  photos_debug (PHOTOS_DEBUG_GEGL, "GEGL: Threads: %d", threads);
+  photos_debug (PHOTOS_DEBUG_GEGL, "GEGL: Using OpenCL: %s", use_opencl ? "yes" : "no");
+
+  for (i = 0; i < G_N_ELEMENTS (REQUIRED_GEGL_OPS); i++)
+    {
+      if (!gegl_has_operation (REQUIRED_GEGL_OPS[i]))
+        {
+          g_warning ("Unable to find GEGL operation %s: Check your GEGL install", REQUIRED_GEGL_OPS[i]);
+          ret_val = FALSE;
+          break;
+        }
+    }
+
+  return ret_val;
+}
