@@ -32,6 +32,17 @@
 #include "photos-search-context.h"
 
 
+struct _PhotosOffsetOverviewController
+{
+  PhotosOffsetController parent_instance;
+};
+
+struct _PhotosOffsetOverviewControllerClass
+{
+  PhotosOffsetControllerClass parent_class;
+};
+
+
 G_DEFINE_TYPE (PhotosOffsetOverviewController, photos_offset_overview_controller, PHOTOS_TYPE_OFFSET_CONTROLLER);
 
 
@@ -50,8 +61,8 @@ photos_offset_overview_controller_get_query (PhotosOffsetController *offset_cntr
 
 static GObject *
 photos_offset_overview_controller_constructor (GType type,
-                                                guint n_construct_params,
-                                                GObjectConstructParam *construct_params)
+                                               guint n_construct_params,
+                                               GObjectConstructParam *construct_params)
 {
   static GObject *self = NULL;
 
